"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var AlertcardComponent = (function () {
    function AlertcardComponent() {
        this.save = new core_1.EventEmitter();
    }
    // User clicked a delivery option checkbox
    AlertcardComponent.prototype.deliveryOptionChanged = function (id) {
        var foundAt = this.deliverTo.indexOf(id);
        if (foundAt >= 0) {
            // Remove
            this.deliverTo.splice(foundAt, 1);
        }
        else {
            // Add
            this.deliverTo.push(id);
        }
        this.isDirty = true;
    };
    AlertcardComponent.prototype.ngOnInit = function () {
        this.isDirty = false;
        // Save the original values passed into this component
        this.active = this.alertPref.active;
        this.deliverTo = new Array();
        for (var _i = 0, _a = this.alertPref.deliverTo; _i < _a.length; _i++) {
            var i = _a[_i];
            this.deliverTo.push(i);
        }
        // Combine parameter defintion and value into one array
        this.parameters = new Array();
        var alertDefParameters = this.alertPref.alertDef.parameters;
        var _loop_1 = function (parameter) {
            var pref = this_1.alertPref.parameters.find(function (p) { return p.parameterId === parameter.id; });
            var value = this_1.externalParameters ? this_1.externalParameters[parameter.id.toLowerCase()] : null;
            if (!value) {
                value = pref ? pref.value : '';
            }
            this_1.parameters.push({ id: parameter.id, label: parameter.label, value: value });
        };
        var this_1 = this;
        for (var _b = 0, alertDefParameters_1 = alertDefParameters; _b < alertDefParameters_1.length; _b++) {
            var parameter = alertDefParameters_1[_b];
            _loop_1(parameter);
        }
    };
    AlertcardComponent.prototype.statusChanged = function () {
        this.isDirty = true;
        // If turning off, then go ahead and save
        if (!this.active) {
            this.savePref();
        }
    };
    AlertcardComponent.prototype.parameterChanged = function () {
        this.isDirty = true;
    };
    // Save the user inputs back to the passed in preference object
    AlertcardComponent.prototype.savePref = function () {
        this.alertPref.active = this.active;
        this.alertPref.deliverTo = new Array();
        for (var _i = 0, _a = this.deliverTo; _i < _a.length; _i++) {
            var i = _a[_i];
            this.alertPref.deliverTo.push(i);
        }
        this.alertPref.parameters = new Array();
        for (var _b = 0, _c = this.parameters; _b < _c.length; _b++) {
            var p = _c[_b];
            this.alertPref.parameters.push({ parameterId: p.id, value: p.value });
        }
        this.isDirty = false;
        this.save.emit(null);
    };
    // Reinitilaze with original values
    AlertcardComponent.prototype.cancelPref = function () {
        this.ngOnInit();
    };
    return AlertcardComponent;
}());
AlertcardComponent.decorators = [
    { type: core_1.Component, args: [{
                selector: 'np-alertcard',
                template: "\n    <div class=\"card fluid\">\n      <div class=\"section\">\n        <div>\n          <div>\n            <div style=\"float:right;\">\n              <np-slider [(state)]=\"active\" (stateChange)=\"statusChanged()\"></np-slider>\n            </div>\n            <div class=\"np-alert-name\">{{alertPref.alertDef.name}}</div>\n            <div class=\"np-alert-description\">{{alertPref.alertDef.description}}</div>\n          </div>\n        </div>\n        <div *ngIf=\"active\">\n          <div class=\"np-alert-parameters\">\n            <div  *ngFor=\"let parameter of parameters\">\n              <div *ngIf=\"parameter.label\">\n                <label>{{parameter.label}}</label>\n                <input  [(ngModel)]=\"parameter.value\" (keyup)=\"parameterChanged()\">\n              </div>\n            </div>\n          </div>\n          <div class=\"np-alert-deliver-to\">\n            <label for=\"options\">Deliver To:</label>\n            <div *ngFor=\"let option of deliveryOptions\">\n              <div *ngIf=\"option.id\">\n                <input type=\"checkbox\" name=\"options\" value=\"{{option.id}}\" id=\"option{{alertPref.alertId}}{{option.id}}\" tabindex=\"0\" (click)=\"deliveryOptionChanged(option.id)\"\n                  [checked]=\"this.deliverTo.indexOf(option.id) >= 0\">\n                <label for=\"option{{alertPref.alertId}}{{option.id}}\">{{option.name || option.value}}</label>\n                <svg *ngIf=\"option.deliveryType =='text'\" class=\"np-icon\"><use xlink:href=\"#chat\" /></svg>\n                <svg *ngIf=\"option.deliveryType =='email'\" class=\"np-icon\"><use xlink:href=\"#email\" /></svg>\n              </div>\n            </div>\n          </div>\n          <div>\n            <span *ngIf=\"isDirty\" class=\"np-alert-save-cancel\">\n              <button  (click)=\"savePref()\">Save</button>\n              <button  (click)=\"cancelPref()\">Cancel</button>\n            </span>\n          </div>\n        </div>\n      </div>\n    </div>\n  ",
                styles: ["\n\n    h1, h2, h3, h4, h5, h6 {\n      line-height: 1.2em;\n      margin: 0.75rem 0.5rem;\n      font-weight: 500;\n    }\n\n    h1 small, h2 small, h3 small, h4 small, h5 small, h6 small {\n      color: #424242;\n      display: block;\n      margin-top: -0.25rem;\n    }\n    .np-icon {\n      width: 16px;\n      height: 13px;\n    }\n    .np-alert-name{\n      font-weight: bold;\n      font-size: 12pt;\n    }\n    .np-alert-description{\n      font-size: 12pt;\n    }\n\n    /*\n      Definitions for cards and containers.\n    */\n    .card {\n      display: -webkit-box;\n      -webkit-box-orient: vertical;\n      -webkit-box-pack: justify;\n      -webkit-box-align: center;\n      display: -webkit-flex;\n      display: flex;\n      -webkit-flex-direction: column;\n      flex-direction: column;\n      -webkit-justify-content: space-between;\n      justify-content: space-between;\n      -webkit-align-self: center;\n      align-self: center;\n      position: relative;\n      width: 100%;\n      background: #fafafa;\n      border: 0.0625rem solid #acacac;\n      margin: 0.5rem;\n      overflow: hidden;\n    }\n\n    .card > .section {\n      box-sizing: border-box;\n      margin: 0;\n      border: 0;\n      border-radius: 0;\n      border-bottom: 0.0625rem solid #c9c9c9;\n      padding: 0.5rem;\n      width: 100%;\n    }\n\n    .card > .section:last-child {\n      border-bottom: 0;\n    }\n\n    @media screen and (min-width: 320px) {\n      .card {\n        max-width: 320px;\n      }\n    }\n\n    .card.fluid {\n      max-width: 100%;\n      width: auto;\n    }\n\n    .np-alert-parameters {\n      float: left;\n      padding: 20px;\n    }\n\n    .np-alert-deliver-to {\n      float: left;\n      padding: 20px;\n    }\n\n    .np-alert-save-cancel {\n      float:right;\n      padding: 10px;\n    }\n  "]
            },] },
];
/** @nocollapse */
AlertcardComponent.ctorParameters = function () { return []; };
AlertcardComponent.propDecorators = {
    'alertPref': [{ type: core_1.Input },],
    'deliveryOptions': [{ type: core_1.Input },],
    'externalParameters': [{ type: core_1.Input },],
    'save': [{ type: core_1.Output },],
};
exports.AlertcardComponent = AlertcardComponent;
var ParameterInput = (function () {
    function ParameterInput() {
    }
    return ParameterInput;
}());
exports.ParameterInput = ParameterInput;
//# sourceMappingURL=alertcard.component.js.map